GeneralRegister

Enum GeneralRegister 

#[repr(u8)]
pub enum GeneralRegister {
Show 20 variants ChipVersion = 0, Control = 7, SoftReset = 12, HdrEnable = 15, AdcResCtrl = 28, RowNoiseCorrCtrl = 112, RowNoiseConstant = 114, TestPattern = 127, TiledDigitalGain = 128, AgcAecDesiredBin = 165, AecUpdate = 166, AecLowpass = 168, AgcUpdate = 169, AgcLowpass = 170, AgcMaxGain = 171, MinExposure = 172, MaxExposure = 173, AecAgcEnable = 175, AgcAecPixelCount = 176, RegisterLock = 254,
}

Variants



ChipVersion = 0



Control = 7

Control register: used for eg switching config contexts



SoftReset = 12

Soft Reset of Logic



HdrEnable = 15

High Dynamic Range enable



AdcResCtrl = 28

ADC Resolution Control



RowNoiseCorrCtrl = 112

Row Noise Correction Control 1



RowNoiseConstant = 114

Row Noise Constant



TestPattern = 127

Test pattern storage



TiledDigitalGain = 128

Tiled digital gain



AgcAecDesiredBin = 165

Desired luminance



AecUpdate = 166

Exposure skip (number of frames to skip between changes in AEC, 0..15)



AecLowpass = 168

AEC Lowpass filter (0..2)



AgcUpdate = 169

Gain skip (number of frames to skip between changes in AGC, 0-15)



AgcLowpass = 170

AGC Lowpass filter (0..2)



AgcMaxGain = 171

AGC Max Gain



MinExposure = 172

Minimum coarse shutter width



MaxExposure = 173

Maximum coarse shutter width



AecAgcEnable = 175

AEC/AGC Enable



AgcAecPixelCount = 176

Histogram pixel count



RegisterLock = 254

Register locking (either All/RW or just RO)